import { createSignal, onCleanup, createComponent, Show, createEffect, createMemo, For, createRenderEffect } from "solid-js";
import { template, insert, style } from "solid-js/web";
import { t as testBracket, o as addListener2, j as getPosition, v as voidlessLangs, m as voidTags } from "../local-DVlaAAgt.js";
import { a as addListener, d as doc } from "../core-KRqi5ptr.js";
import { createCopyButton } from "../extensions/copy-button/index.js";
import { t as tokenizeText, l as languages, h as highlightTokens } from "../index-k28m3HFc.js";
let stack = [];
let sp$1;
const addAlias = (token, newAlias = "bracket-error") => {
  let alias = token.alias;
  token.alias = (alias ? alias + " " : "") + newAlias;
};
const matchRecursive = (tokens, pairs) => {
  let token;
  let i = 0;
  for (; token = tokens[i++]; ) {
    if (typeof token == "string") continue;
    let content = token.content;
    let alias = token.alias;
    if (Array.isArray(content)) {
      matchRecursive(content, pairs);
    } else if ((alias || token.type) == "punctuation") {
      let last = token.length - 1;
      let bracketType = testBracket(content, pairs, last);
      if (bracketType) {
        if (bracketType % 2) stack[sp$1++] = [token, bracketType + 1];
        else {
          let i2 = sp$1;
          let found;
          while (i2) {
            let entry = stack[--i2];
            if (bracketType == entry[1]) {
              let alias2 = "bracket-level-" + i2 % 12;
              let j = i2;
              while (++j < sp$1) {
                addAlias(stack[j][0]);
              }
              addAlias(token, alias2);
              addAlias(entry[0], alias2);
              sp$1 = i2;
              i2 = 0;
              found = true;
            }
          }
          if (!found) addAlias(token);
        }
      }
    }
  }
};
const rainbowBrackets = (pairs = "()[]{}") => {
  return (tokens) => {
    sp$1 = 0;
    matchRecursive(tokens, pairs);
    stack = [];
  };
};
const addCopyButton = (codeBlock, props) => {
  const container = createCopyButton();
  const btn = container.firstChild;
  addListener(btn, "click", () => {
    btn.setAttribute("aria-label", "Copied!");
    if (!navigator.clipboard?.writeText(props.code)) {
      const selection = getSelection();
      const range = new Range();
      selection.removeAllRanges();
      selection.addRange(range);
      range.setStartAfter(codeBlock.lines[0]);
      range.setEndAfter(codeBlock.wrapper);
      doc.execCommand("copy");
      range.collapse();
    }
  });
  addListener(btn, "pointerenter", () => btn.setAttribute("aria-label", "Copy"));
  return container;
};
let counter = 0;
let sp;
const createTooltip = /* @__PURE__ */ template(
  "<div class=pce-tooltip style=z-index:5;top:auto;display:flex><div></div><div class=pce-hover-tooltip style=flex-shrink:0>"
);
const getLanguageAt = (token) => {
  return /language-(\S*)/.exec(token.closest("[class*=language-").className)[1];
};
const addHoverDescriptions = (callback, options = {}) => (codeBlock) => {
  let current;
  const { above, maxHeight, maxWidth } = options;
  const container = createTooltip();
  const pre = codeBlock.container;
  const style2 = container.style;
  const [spacer, tooltip] = container.children;
  const wrapper = codeBlock.wrapper;
  const id = tooltip.id = "pce-hover-" + counter++;
  const [open, setOpen] = createSignal(false);
  const show = (target) => {
    const types = target.className.slice(6).split(" ");
    const text = target.textContent;
    const content = callback(types, getLanguageAt(target), text, target);
    if (content) {
      let { left, right, top, bottom, height } = getPosition(codeBlock, target);
      let { clientHeight, clientWidth } = pre;
      let max = bottom > top ? bottom : top;
      tooltip.style.maxWidth = `min(${maxWidth ? maxWidth + "," : ""}${clientWidth}px - var(--padding-left) - 1em)`;
      tooltip.style.maxHeight = `min(${maxHeight ? maxHeight + "," : ""}${max}px, ${clientHeight * 0.6}px - 2em)`;
      spacer.style.width = (pre.matches(".pce-rtl") ? right : left) + "px";
      tooltip.textContent = "";
      tooltip.append(...content);
      setOpen(true);
      let placeAbove = !above == top > bottom && (above ? top : bottom) < container.clientHeight ? !above : above;
      style2[placeAbove ? "bottom" : "top"] = height + (placeAbove ? bottom : top) + "px";
      style2[placeAbove ? "top" : "bottom"] = "auto";
      current?.removeAttribute("aria-describedby");
      target.setAttribute("aria-describedby", id);
      current = target;
    } else hide();
  };
  const hide = () => {
    current?.removeAttribute("aria-describedby");
    setOpen(false);
  };
  onCleanup(addListener2(tooltip, "pointerleave", hide));
  onCleanup(
    addListener2(wrapper, "pointerover", (e) => {
      const target = e.target;
      if (!tooltip.contains(target)) {
        if (target.matches(".token") && (e.pointerType != "mouse" || !e.buttons) && !target.childElementCount) {
          show(target);
        } else hide();
      }
    })
  );
  return createComponent(Show, {
    get when() {
      return open();
    },
    children: container
  });
};
const highlightBracketPairsOnHover = (pairs = "()[]{}") => (codeBlock, props) => {
  highlightPairsOnHover(
    codeBlock,
    props,
    "active-bracket",
    "punctuation",
    (token, stack2, map) => {
      const text = token.textContent;
      const last = text.length - 1;
      const bracketType = testBracket(text, pairs, last);
      if (bracketType) {
        if (bracketType % 2) stack2[sp++] = [token, bracketType + 1];
        else {
          for (let i = sp; i; ) {
            let [el, type] = stack2[--i];
            if (bracketType == type) {
              map.set(token, el);
              map.set(el, token);
              if (el.nextSibling == token) {
                el.textContent += token.textContent;
                token.textContent = "";
              }
              sp = i;
              i = 0;
            }
          }
        }
      }
    }
  );
};
const highlightTagPairsOnHover = () => (codeBlock, props) => {
  const partialTags = [];
  const matchTag = (nameEl, isClosing, lastChild, stack2, map) => {
    const tagName = nameEl.textContent;
    const notSelfClosing = !lastChild.textContent[1] && (voidlessLangs.has(getLanguageAt(nameEl)) || !voidTags.test(tagName));
    if (notSelfClosing) {
      if (isClosing) {
        for (let i = sp; i; ) {
          let entry = stack2[--i];
          if (tagName == entry[1]) {
            map.set(nameEl, entry[0]);
            map.set(entry[0], nameEl);
            sp = i;
            i = 0;
          }
        }
      } else {
        stack2[sp++] = [nameEl, tagName];
      }
    }
  };
  highlightPairsOnHover(codeBlock, props, "active-tagname", "tag", (token, stack2, map) => {
    const children = token.children;
    const text = token.textContent;
    const lastChild = children[children.length - 1];
    const second = children[1];
    const hasClosingPunctuation = lastChild?.matches(".punctuation");
    if (second?.matches(".tag")) {
      if (hasClosingPunctuation) {
        matchTag(second, text[1] == "/", lastChild, stack2, map);
      } else {
        partialTags.push([second, text[1] == "/"]);
      }
    } else if (hasClosingPunctuation && partialTags[0]) {
      matchTag(...partialTags.pop(), lastChild, stack2, map);
    }
  });
};
const highlightPairsOnHover = (codeBlock, props, highlightClass, tokenName, forEachToken) => {
  let cache;
  const active = [[], []];
  const wrapper = codeBlock.wrapper;
  const toggleHighlight = (index, add) => active[index].forEach((el) => el.classList.toggle(highlightClass, !!add));
  const setCache = () => {
    cache = /* @__PURE__ */ new WeakMap();
    let tokens = wrapper.getElementsByClassName(tokenName);
    let i = sp = 0;
    let stack2 = [];
    let token;
    while (token = tokens[i++]) {
      forEachToken(token, stack2, cache);
    }
  };
  const handler = (e) => {
    const target = e.target.closest("." + tokenName);
    const index = e.type == "click" ? 0 : 1;
    if (active[0].includes(target)) return;
    if (index && (e.pointerType != "mouse" || e.buttons)) return;
    if (!cache) setCache();
    toggleHighlight(index);
    active[index] = [];
    const other = cache.get(target);
    if (other) {
      active[1] = [];
      active[index] = [target, other];
      toggleHighlight(index, true);
    }
  };
  createEffect(() => {
    props.code;
    props.language;
    props.preserveIndent;
    props.wordWrap;
    props.tabSize;
    props.onTokenize;
    cache = null;
  });
  onCleanup(addListener2(wrapper, "click", handler));
  onCleanup(addListener2(wrapper, "pointerover", handler));
  onCleanup(
    addListener2(wrapper, "pointerleave", () => {
      toggleHighlight(1);
      active[1] = [];
    })
  );
};
const block = /* @__PURE__ */ template("<pre><code class=pce-wrapper><div class=pce-overlays>");
const line = /* @__PURE__ */ template("<div class=pce-line>");
const CodeBlock = (props) => {
  const hasGuides = createMemo(() => props.guideIndents && !props.rtl);
  const preserve = createMemo(() => props.preserveIndent ?? props.wordWrap);
  const lines = createMemo(() => {
    let code = preserve() ? props.code.replace(/\t/g, " ".repeat(props.tabSize || 2)) : props.code;
    let tokens = tokenizeText(
      code.includes("\r") ? code.replace(/\r\n?/g, "\n") : code,
      languages[props.language] || {}
    );
    props.onTokenize?.(tokens);
    return highlightTokens(tokens).split("\n");
  });
  const container = block();
  const wrapper = container.firstChild;
  const lineEls = wrapper.children;
  const indents = createMemo(() => {
    if (preserve() || hasGuides()) {
      const code = props.code;
      const tabSize = props.tabSize || 2;
      const lines2 = code.split("\n");
      const l = lines2.length;
      const result = Array(l).fill(0);
      for (let prevIndent = 0, emptyPos = -1, i = 0; i < l; i++) {
        let line2 = lines2[i];
        let l2 = line2.search(/\S/);
        let indent = 0;
        if (l2 < 0) {
          if (emptyPos < 0) emptyPos = i;
        } else {
          for (let i2 = 0; i2 < l2; ) {
            indent += line2[i2++] == "	" ? tabSize - indent % tabSize : 1;
          }
          if (emptyPos + 1) {
            if (indent != prevIndent) prevIndent = Math.min(indent, prevIndent) + 1;
            while (emptyPos < i) {
              result[emptyPos++] = prevIndent;
            }
          }
          result[i] = prevIndent = indent;
          emptyPos = -1;
        }
      }
      return result;
    }
  });
  const codeBlock = {
    container,
    wrapper,
    lines: lineEls
  };
  insert(
    lineEls[0],
    createComponent(For, {
      get each() {
        return props.overlays;
      },
      children: (overlay) => overlay(codeBlock, props)
    }),
    null
  );
  insert(
    wrapper,
    createComponent(For, {
      get each() {
        return lines();
      },
      children: (html, i) => {
        const div = line();
        div.innerHTML = html + "\n";
        createRenderEffect(() => {
          div.style.setProperty("--indent", `${indents()?.[i()] || 0}ch`);
        });
        return div;
      }
    }),
    null
  );
  createRenderEffect(() => {
    let propClass = props.class;
    container.className = `prism-code-editor language-${props.language}${props.lineNumbers ? " show-line-numbers" : ""} pce-${props.wordWrap ? "" : "no"}wrap${props.rtl ? " pce-rtl" : ""}${preserve() ? " pce-preserve" : ""}${hasGuides() ? " pce-guides" : ""}${propClass ? " " + propClass : ""}`;
  });
  createRenderEffect(
    (prev) => style(container, props.style, prev)
  );
  createRenderEffect(() => {
    const style2 = container.style;
    const offset = props.lineNumberStart - 1 || 0;
    style2.setProperty("--tab-size", props.tabSize || 2);
    style2.setProperty("--number-width", (0 | Math.log10(lines().length + offset)) + 1 + ".001ch");
    style2.counterReset = `line ${offset}`;
  });
  return container;
};
export {
  CodeBlock,
  addCopyButton,
  addHoverDescriptions,
  highlightBracketPairsOnHover,
  highlightTagPairsOnHover,
  rainbowBrackets
};
//# sourceMappingURL=index.js.map
