import { mergeProps, createSignal, createRenderEffect, on, untrack, onMount, createComponent, For } from "solid-js";
import { t as tokenizeText, l as languages, h as highlightTokens } from "./index-k28m3HFc.js";
import { template, style, insert } from "solid-js/web";
const Editor = (props) => {
  let handleSelecionChange = true;
  let activeLine;
  let prevLines = [];
  let language = "";
  let value = "";
  let prevValue;
  let prevClass;
  let activeLineNumber = 0;
  let lineCount = 0;
  let isFirstRender = true;
  let editorProps = mergeProps({ language: "text", value }, props);
  const container = editorTemplate();
  const wrapper = container.firstChild;
  const lines = wrapper.children;
  const overlays = lines[0];
  const textarea = overlays.firstChild;
  const getInputSelection = () => [
    textarea.selectionStart,
    textarea.selectionEnd,
    textarea.selectionDirection
  ];
  const [selection, setSelection] = createSignal(getInputSelection());
  const [focused, setFocused] = createSignal(false);
  const [tokens, setTokens] = createSignal([]);
  const updateSelection = (force) => {
    if (force || handleSelecionChange) {
      const selection2 = getInputSelection();
      const newLine = lines[activeLineNumber = numLines(value, 0, selection2[selection2[2] < "f" ? 0 : 1])];
      if (newLine != activeLine) {
        activeLine?.classList.remove("active-line");
        newLine.classList.add("active-line");
        activeLine = newLine;
      }
      setSelection(selection2);
    }
  };
  const keyCommandMap = {
    Escape() {
      textarea.blur();
    }
  };
  const inputCommandMap = {};
  const update = () => {
    setTokens(tokenizeText(value = textarea.value, languages[language] || {}));
  };
  const editor = {
    inputCommandMap,
    keyCommandMap,
    extensions: {},
    props: editorProps,
    get value() {
      return value;
    },
    selection,
    tokens,
    focused,
    get activeLine() {
      return activeLineNumber;
    },
    container,
    wrapper,
    lines,
    textarea,
    update,
    getSelection: getInputSelection
  };
  createRenderEffect(() => {
    let readOnly = !!editorProps.readOnly;
    textarea.inputMode = readOnly ? "none" : "";
    textarea.setAttribute("aria-readonly", readOnly);
  });
  createRenderEffect(() => {
    let propClass = editorProps.class;
    let newClass = `prism-code-editor language-${editorProps.language}${editorProps.lineNumbers == false ? "" : " show-line-numbers"} pce-${editorProps.wordWrap ? "" : "no"}wrap${editorProps.rtl ? " pce-rtl" : ""} pce-${selection()[0] < selection()[1] ? "has" : "no"}-selection${focused() ? " pce-focus" : ""}${editorProps.readOnly ? " pce-readonly" : ""}${propClass ? " " + propClass : ""}`;
    if (prevClass != newClass) container.className = prevClass = newClass;
  });
  createRenderEffect(() => {
    container.style.tabSize = editorProps.tabSize || 2;
  });
  createRenderEffect(
    on(selection, (s) => {
      if (!isFirstRender) editorProps.onSelectionChange?.(s, value, editor);
    })
  );
  createRenderEffect(() => {
    tokens();
    if (isFirstRender) return;
    let newLines = highlightTokens(tokens()).split("\n");
    let start = 0;
    let end2 = lineCount;
    let end1 = lineCount = newLines.length;
    while (newLines[start] == prevLines[start] && start < end1) ++start;
    while (end1 && newLines[--end1] == prevLines[--end2]) ;
    if (start == end1 && start == end2) lines[start + 1].innerHTML = newLines[start] + "\n";
    else {
      let insertStart = end2 < start ? end2 : start - 1;
      let i = insertStart;
      let newHTML = "";
      while (i < end1) newHTML += `<div class=pce-line aria-hidden=true>${newLines[++i]}
</div>`;
      for (i = end1 < start ? end1 : start - 1; i < end2; i++) lines[start + 1].remove();
      if (newHTML) lines[insertStart + 1].insertAdjacentHTML("afterend", newHTML);
      for (i = insertStart + 1; i < lineCount; ) lines[++i].setAttribute("data-line", i);
      container.style.setProperty("--number-width", Math.ceil(Math.log10(lineCount + 1)) + ".001ch");
    }
    updateSelection(true);
    if (handleSelecionChange) setTimeout(setTimeout, 0, () => handleSelecionChange = true);
    prevLines = newLines;
    handleSelecionChange = false;
  });
  createRenderEffect(
    on(tokens, () => {
      if (!isFirstRender) editorProps.onUpdate?.(value, editor);
    })
  );
  createRenderEffect(() => {
    let newValue = editorProps.value;
    let isFocused = untrack(focused);
    if (prevValue != newValue) {
      if (!isFocused) textarea.remove();
      textarea.value = prevValue = newValue;
      textarea.selectionEnd = 0;
      if (!isFocused) overlays.prepend(textarea);
    }
    language = editorProps.language;
    isFirstRender = false;
    update();
  });
  createRenderEffect(
    (prev) => style(container, props.style, prev)
  );
  onMount(() => {
    editorProps.onMount?.(editor);
  });
  addListener(textarea, "keydown", (e) => {
    keyCommandMap[e.key]?.(e, getInputSelection(), value) && preventDefault(e);
  });
  addListener(textarea, "beforeinput", (e) => {
    if (editorProps.readOnly || e.inputType == "insertText" && inputCommandMap[e.data]?.(e, getInputSelection(), value))
      preventDefault(e);
  });
  addListener(textarea, "input", update);
  addListener(textarea, "blur", () => {
    selectionChange = null;
    setFocused(false);
  });
  addListener(textarea, "focus", () => {
    selectionChange = updateSelection;
    setFocused(true);
  });
  addListener(textarea, "selectionchange", (e) => {
    updateSelection();
    preventDefault(e);
  });
  insert(
    overlays,
    createComponent(For, {
      get each() {
        return editorProps.extensions;
      },
      children: (extension) => extension(editor)
    }),
    null
  );
  return container;
};
const doc = "u" > typeof window ? document : null;
const languageMap = {};
const editorTemplate = /* @__PURE__ */ template(
  "<div><div class=pce-wrapper><div class=pce-overlays><textarea class=pce-textarea spellcheck=false autocapitalize=off autocomplete=off>"
);
const preventDefault = (e) => {
  e.preventDefault();
  e.stopImmediatePropagation();
};
const addListener = (target, type, listener, options) => target.addEventListener(type, listener, options);
const numLines = (str, start = 0, end = Infinity) => {
  let count = 1;
  for (; (start = str.indexOf("\n", start) + 1) && start <= end; count++) ;
  return count;
};
if (doc) addListener(doc, "selectionchange", () => selectionChange?.());
let selectionChange;
export {
  Editor as E,
  addListener as a,
  doc as d,
  languageMap as l,
  numLines as n,
  preventDefault as p,
  selectionChange as s
};
//# sourceMappingURL=core-KRqi5ptr.js.map
