import { EditorProps, Language } from './types';
/**
 * The core editor component of the library.
 * @param props Props to customize some of the appearance and behavior of the editor.
 * @returns The container for the editor.
 */
declare const Editor: (props: Partial<EditorProps>) => HTMLDivElement;
/** Equivalent to `document` in a browser setting, `null` otherwise. */
declare const doc: Document | null;
/** Object storing all language specific behavior. */
declare const languageMap: Record<string, Language>;
declare const preventDefault: (e: Event) => void;
declare const addListener: <T extends keyof HTMLElementEventMap>(target: HTMLElement, type: T, listener: (this: HTMLElement, ev: HTMLElementEventMap[T]) => any, options?: boolean | AddEventListenerOptions) => void;
/**
 * Counts number of lines in the string between `start` and `end`.
 * If start and end are omitted, the whole string is searched.
 */
declare const numLines: (str: string, start?: number, end?: number) => number;
declare let selectionChange: null | ((force?: boolean) => void);
export { Editor, addListener, preventDefault, doc, languageMap, numLines, selectionChange };
