import { createEffect } from "solid-js";
import { template as template$1 } from "solid-js/web";
const getIndentGuides = (code, tabSize) => {
  const lines = code.split("\n");
  const l = lines.length;
  const stack = [];
  const results = [];
  for (let prevIndent = 0, emptyPos = -1, i = 0, p = 0; ; i++) {
    let last = i == l;
    let line = lines[i];
    let pos = last ? 0 : line.search(/\S/);
    let indent = 0;
    let j = 0;
    if (pos < 0) {
      if (emptyPos < 0) emptyPos = i;
    } else {
      for (; j < pos; ) {
        indent += line[j++] == "	" ? tabSize - indent % tabSize : 1;
      }
      if (indent) indent = Math.ceil(indent / tabSize);
      for (j = indent; j < prevIndent; j++) {
        stack[j][2] = (emptyPos < 0 || j == indent && !last ? i : emptyPos) - stack[j][0];
      }
      for (j = prevIndent; j < indent; ) {
        results[p++] = stack[j] = [emptyPos < 0 || j > prevIndent ? i : emptyPos, j++, 0];
      }
      emptyPos = -1;
      prevIndent = indent;
    }
    if (last) break;
  }
  return results;
};
const template = /* @__PURE__ */ template$1(
  "<div class=guide-indents style=left:var(--padding-left);bottom:auto;right:auto>	"
);
const indentTemplate = /* @__PURE__ */ template$1(
  "<div style=width:1px;position:absolute;background:var(--bg-guide-indent)>"
);
const indentGuides = () => (editor) => {
  let tabSize;
  let prevLength = 0;
  let lineIndentMap = [];
  let active;
  let prevValue = "";
  const container = template();
  const lines = [];
  const indents = [];
  createEffect(() => {
    const value = editor.value;
    const wordWrap = editor.props.wordWrap;
    tabSize = editor.props.tabSize || 2;
    editor.selection();
    if (!wordWrap && value != prevValue) {
      lineIndentMap = [];
      const newIndents = getIndentGuides(value, tabSize);
      const l = newIndents.length;
      for (let i = 0, prev = [], next = newIndents[0]; next; i++) {
        const style = (lines[i] ||= indentTemplate()).style;
        const [top, left, height] = next;
        const old = indents[i];
        next = newIndents[i + 1];
        if (top != old?.[0]) style.top = top + "00%";
        if (left != old?.[1]) style.left = left + "00%";
        if (height != old?.[2]) style.height = height + "00%";
        const isSingleIndent = prev[0] != top && next?.[0] != top;
        const isSingleOutdent = prev[0] + prev[1] != top + height && next?.[0] + next?.[1] != top + height;
        for (let j = -isSingleIndent, l2 = height + isSingleOutdent; j < l2; j++)
          lineIndentMap[j + top] = i;
        prev = indents[i] = newIndents[i];
      }
      for (let i = l; i < prevLength; ) lines[i++].remove();
      container.append(...lines.slice(prevLength, prevLength = l));
    }
    const newActive = lines[lineIndentMap[editor.activeLine - 1]];
    if (newActive != active) {
      if (active) active.className = "";
      if (newActive) newActive.className = "active-indent";
      active = newActive;
    }
    container.style.display = wordWrap ? "none" : "";
    prevValue = value;
  });
  return container;
};
export {
  getIndentGuides,
  indentGuides
};
//# sourceMappingURL=guides.js.map
