import { createComputed, onCleanup } from "solid-js";
import { t as testBracket } from "../../local-DVlaAAgt.js";
const matchBrackets = (rainbowBrackets = true, pairs = "()[]{}") => {
  return (editor) => {
    let bracketIndex;
    let sp;
    const stack = [];
    const brackets = [];
    const pairMap = [];
    const matchRecursive = (tokens, position, level) => {
      let token;
      let i = 0;
      for (; token = tokens[i++]; ) {
        let length = token.length;
        if (typeof token != "string") {
          let content = token.content;
          if (Array.isArray(content)) {
            matchRecursive(content, position, sp + level);
          } else if ((token.alias || token.type) == "punctuation") {
            let bracketType = testBracket(content, pairs, length - 1);
            let isOpening = bracketType % 2;
            if (bracketType) {
              brackets[bracketIndex] = [
                token,
                position,
                position + length,
                sp,
                content,
                !!isOpening
              ];
              if (isOpening) stack[sp++] = [bracketIndex, bracketType + 1];
              else {
                for (let i2 = sp; i2; ) {
                  let entry = stack[--i2];
                  if (bracketType == entry[1]) {
                    pairMap[pairMap[bracketIndex] = entry[0]] = bracketIndex;
                    brackets[bracketIndex][3] = i2 + level;
                    sp = i2;
                    i2 = 0;
                  }
                }
              }
              bracketIndex++;
            }
          }
        }
        position += length;
      }
    };
    editor.extensions.matchBrackets = {
      brackets,
      pairs: pairMap
    };
    createComputed(() => {
      pairMap.length = brackets.length = sp = bracketIndex = 0;
      matchRecursive(editor.tokens(), 0, 0);
      if (rainbowBrackets) {
        for (let i = 0, bracket; bracket = brackets[i]; ) {
          let alias = bracket[0].alias;
          bracket[0].alias = (alias ? alias + " " : "") + `bracket-${i++ in pairMap ? "level-" + bracket[3] % 12 : "error"}`;
        }
      }
    });
    onCleanup(() => {
      delete editor.extensions.matchBrackets;
    });
  };
};
export {
  matchBrackets
};
//# sourceMappingURL=index.js.map
