import { createSignal, createEffect, on, onCleanup, untrack } from "solid-js";
import { a as addListener, p as preventDefault, n as numLines, d as doc } from "./core-KRqi5ptr.js";
import { c as createReplaceAPI } from "./replace-Cfmepm6X.js";
import { a as addTextareaListener, b as getModifierCode, f as isMac, n as isWebKit, u as updateNode, e as getLineStart, h as getLineEnd, d as getLineBefore, r as regexEscape } from "./local-DVlaAAgt.js";
import { g as getStyleValue } from "./other-EdiSn7BB.js";
import { template as template$1 } from "solid-js/web";
import { c as createSearchAPI } from "./search-DnuO-Q5a.js";
const shortcut = ` (Alt+${isMac ? "Cmd+" : ""}`;
const template = /* @__PURE__ */ template$1(
  `<div class=prism-search-container style=display:none;align-items:flex-start;justify-content:flex-end><div dir=ltr class=prism-search><button type=button aria-expanded=false title="Toggle Replace" class=pce-expand></button><div spellcheck=false><div><div class="pce-input pce-find"><input autocorrect=off autocapitalize=off placeholder=Find aria-label=Find><button type=button class=prev-match title="Previous Match (Shift+Enter)"></button><button type=button class=next-match title="Next Match (Enter)"></button><div class=search-error></div></div><button type=button class=pce-close title="Close (Esc)"></button></div><div class="pce-input pce-replace"><input autocorrect=off autocapitalize=off placeholder=Replace aria-label=Replace><button type=button title=(Enter)>Replace</button><button type=button title=(${isMac ? "Cmd" : "Ctrl+Alt"}+Enter)>All</button></div><div class=pce-options><div class=pce-match-count>0<span> of </span>0</div><button type=button aria-pressed=false class=pce-regex title="RegExp Search${shortcut}R)"><span aria-hidden=true></span></button><button type=button aria-pressed=false title="Preserve Case${shortcut}P)"><span aria-hidden=true>Aa</span></button><button type=button aria-pressed=false class=pce-whole title="Match Whole Word${shortcut}W)"><span aria-hidden=true>ab</span></button><button type=button aria-pressed=false class=pce-in-selection title="Find in Selection${shortcut}L)">`
);
const toggleAttr = (el, name) => el.setAttribute(name, el.getAttribute(name) == "false");
const searchWidget = () => (editor) => {
  let currentSelection;
  let prevUserSelection;
  let prevLength = 0;
  let prevMargin;
  let selectNext = false;
  let marginTop;
  let prevTokens;
  let matchCase;
  let wholeWord;
  let useRegExp;
  let searchSelection;
  const searchContainer = template();
  const search = searchContainer.firstChild;
  const [toggle, div] = search.children;
  const rows = div.children;
  const [findContainer, closeEl] = rows[0].children;
  const [findInput, prevEl, nextEl, errorEl] = findContainer.children;
  const [replaceInput, replaceEl, replaceAllEl] = rows[1].children;
  const [matchCount, useRegExpEl, matchCaseEl, wholeWordEl, inSelectionEl] = rows[2].children;
  const [current, , total] = matchCount.childNodes;
  const { textarea, container, getSelection, wrapper } = editor;
  const replaceAPI = createReplaceAPI(editor);
  const replaceContainer = replaceAPI.container;
  const [isOpen, setOpen] = createSignal(false);
  const keyCodeButtonMap = {
    80: matchCaseEl,
    87: wholeWordEl,
    82: useRegExpEl,
    76: inSelectionEl
  };
  const startSearch = (selectMatch) => {
    if (selectMatch && !isWebKit) textarea.setSelectionRange(...prevUserSelection);
    const error = replaceAPI.search(
      findInput.value,
      matchCase,
      wholeWord,
      useRegExp,
      searchSelection
    );
    const index = error ? -1 : selectNext ? replaceAPI.next() : replaceAPI.closest();
    updateNode(current, index + 1);
    updateNode(total, replaceAPI.matches.length);
    findContainer.classList.toggle("pce-error", !!error);
    if (error) errorEl.textContent = error;
    else if (selectMatch || selectNext) replaceAPI.selectMatch(index, prevMargin);
  };
  const move = (next) => {
    if (replaceAPI.matches[0]) {
      const index = replaceAPI[next ? "next" : "prev"]();
      replaceAPI.selectMatch(index, prevMargin);
      updateNode(current, index + 1);
    }
  };
  const updateMargin = () => {
    const newMargin = untrack(isOpen) ? getStyleValue(search, "top") + getStyleValue(search, "height") : marginTop;
    const newScroll = container.scrollTop + newMargin - prevMargin;
    wrapper.style.marginTop = newMargin + "px";
    container.scrollTop = newScroll;
    prevMargin = newMargin;
  };
  const resize = () => div.style.setProperty(
    "--search-width",
    `min(${container.clientWidth - 2}px - 2.4em - var(--padding-left),20em)`
  );
  const observer = window.ResizeObserver && new ResizeObserver(resize);
  const replace = () => {
    selectNext = true;
    let index = replaceAPI.replace(replaceInput.value);
    if (index != null) {
      replaceAPI.selectMatch(index, prevMargin);
      updateNode(current, index + 1);
    }
    selectNext = false;
  };
  const replaceAll = () => {
    replaceAPI.replaceAll(replaceInput.value);
  };
  const keydown = (e) => {
    if (e.keyCode >> 1 == 35 && getModifierCode(e) == (isMac ? 4 : 2)) {
      preventDefault(e);
      open();
      let [start, end] = getSelection();
      let value = editor.value;
      let word = value.slice(start, end) || /[_\p{N}\p{L}]*$/u.exec(getLineBefore(value, start))[0] + /^[_\p{N}\p{L}]*/u.exec(value.slice(start))[0];
      if (/^$|\n/.test(word)) startSearch();
      else {
        if (useRegExp) word = regexEscape(word);
        doc.execCommand("insertText", false, word);
        findInput.select();
      }
    }
  };
  const open = (focusInput = true) => {
    if (!untrack(isOpen)) {
      if (marginTop == null) {
        prevMargin = marginTop = getStyleValue(wrapper, "marginTop");
      }
      prevUserSelection = getSelection();
      searchContainer.style.display = "flex";
      observer?.observe(container);
      setOpen(true);
      updateMargin();
      resize();
    }
    if (focusInput) findInput.select();
  };
  const close = (focusTextarea = true) => {
    if (untrack(isOpen)) {
      searchContainer.style.display = "none";
      observer?.disconnect();
      focusTextarea && textarea.focus();
      replaceAPI.stopSearch();
      setOpen(false);
      updateMargin();
    }
  };
  const removeKeydown = addTextareaListener(editor, "keydown", keydown);
  const removeBeforeinput = addTextareaListener(editor, "beforeinput", () => {
    if (isOpen() && searchSelection) currentSelection = getSelection();
  });
  const elementHandlerMap = /* @__PURE__ */ new Map([
    [nextEl, () => move(true)],
    [prevEl, move],
    [closeEl, close],
    [replaceEl, replace],
    [replaceAllEl, replaceAll],
    [
      toggle,
      () => {
        toggleAttr(toggle, "aria-expanded");
        updateMargin();
      }
    ],
    [matchCaseEl, () => matchCase = !matchCase],
    [useRegExpEl, () => useRegExp = !useRegExp],
    [wholeWordEl, () => wholeWord = !wholeWord],
    [
      inSelectionEl,
      () => {
        const value = editor.value;
        if (searchSelection) searchSelection = void 0;
        else {
          searchSelection = getSelection().slice(0, 2);
          if (numLines(value, ...searchSelection) > 1) {
            searchSelection = [
              getLineStart(value, searchSelection[0]),
              getLineEnd(value, searchSelection[1])
            ];
          }
        }
        prevLength = value.length;
      }
    ]
  ]);
  createEffect(() => {
    if (isOpen() && editor.focused()) prevUserSelection = editor.selection();
  });
  createEffect(
    on(editor.selection, () => {
      if (isOpen() && editor.tokens() != prevTokens) {
        const value = editor.value;
        if (searchSelection && currentSelection) {
          const diff = prevLength - (prevLength = value.length);
          const [, end] = currentSelection;
          const [searchStart, searchEnd] = searchSelection;
          if (end <= searchEnd) {
            searchSelection[1] -= diff;
            if (end <= searchStart - +(diff < 0)) searchSelection[0] -= diff;
          }
        }
        startSearch();
        prevTokens = editor.tokens();
      }
    })
  );
  editor.extensions.searchWidget = {
    open(focusInput) {
      open(focusInput);
      startSearch();
    },
    close
  };
  searchContainer.addEventListener("click", (e) => {
    const target = e.target;
    const remove = addTextareaListener(editor, "input", () => target.focus(), true);
    elementHandlerMap.get(target)?.();
    if (target.matches(".pce-options>button")) {
      toggleAttr(target, "aria-pressed");
      startSearch(true);
    }
    remove();
  });
  addListener(findInput, "input", () => isOpen() && startSearch(true));
  searchContainer.addEventListener("keydown", (e) => {
    const shortcut2 = getModifierCode(e);
    const target = e.target;
    const keyCode = e.keyCode;
    const isFind = target == findInput;
    if (shortcut2 == (isMac ? 5 : 1)) {
      if (keyCodeButtonMap[keyCode]) {
        preventDefault(e);
        keyCodeButtonMap[keyCode].click();
      }
    } else if (keyCode == 13 && target.tagName == "INPUT") {
      preventDefault(e);
      if (!shortcut2) isFind ? move(true) : replaceEl.click();
      else if (shortcut2 == 8 && isFind) move();
      else if (shortcut2 == (isMac ? 4 : 3) && !isFind) replaceAllEl.click();
      target.focus();
    } else if (!shortcut2 && keyCode == 27) close();
    else keydown(e);
  });
  onCleanup(() => {
    removeKeydown();
    removeBeforeinput();
    observer?.disconnect();
    delete editor.extensions.searchWidget;
  });
  replaceContainer.className = "pce-matches";
  return [searchContainer, replaceContainer];
};
const highlightSelectionMatches = (caseSensitive, minLength = 1, maxLength = 200) => {
  return (editor) => {
    const searchAPI = createSearchAPI(editor);
    const container = searchAPI.container;
    container.style.zIndex = -1;
    container.className = "selection-matches";
    createEffect(() => {
      let [start, end] = editor.selection();
      let value = untrack(editor.focused) ? editor.value.slice(start, end) : "";
      let pos = start + value.search(/\S/);
      let l = (value = value.trim()).length;
      searchAPI.search(
        minLength > l || l > maxLength ? "" : value,
        caseSensitive,
        false,
        false,
        void 0,
        (mStart, mEnd) => mStart > pos || mEnd <= pos
      );
    });
    return container;
  };
};
const highlightCurrentWord = (filter, includeHyphens) => {
  return (editor) => {
    let noHighlight = false;
    let searchAPI = createSearchAPI(editor);
    let container = searchAPI.container;
    container.style.zIndex = -1;
    container.className = "word-matches";
    createEffect(() => {
      editor.tokens();
      noHighlight = true;
    });
    createEffect(() => {
      const [start, end] = editor.selection();
      const value = editor.value;
      if (start < end || !untrack(editor.focused) || noHighlight) searchAPI.search("");
      else {
        let group = `[_$\\p{L}\\d${includeHyphens && includeHyphens(start) ? "-" : ""}]`;
        let before = value.slice(0, start).match(RegExp(group + "*$", "u"));
        let index = before.index;
        let word = before[0] + value.slice(start).match(RegExp("^" + group + "*", "u"))[0];
        searchAPI.search(
          /^-*(\d|$)/.test(word) || filter && !filter(index, index + word.length) ? "" : word,
          true,
          true,
          false,
          void 0,
          filter,
          RegExp(group + "{2}", "u")
        );
      }
      noHighlight = false;
    });
    return container;
  };
};
const showInvisibles = (alwaysShow) => {
  return (editor) => {
    let prev;
    const searchAPI = createSearchAPI(editor);
    const matches = searchAPI.matches;
    const container = searchAPI.container;
    const nodes = container.children;
    const tabs = [];
    container.className = "pce-invisibles";
    createEffect(() => {
      const value = editor.value;
      const [start, end] = editor.selection();
      if (!alwaysShow || prev != (prev = value)) {
        searchAPI.search(" |	", true, false, true, alwaysShow ? void 0 : [start, end]);
        for (let i = 0, l = matches.length; i < l; i++) {
          if (value[matches[i][0]] == "	" == !tabs[i]) {
            nodes[i].className = (tabs[i] = !tabs[i]) ? "pce-tab" : "";
          }
        }
      }
    });
    return container;
  };
};
export {
  highlightCurrentWord as a,
  showInvisibles as b,
  highlightSelectionMatches as h,
  searchWidget as s
};
//# sourceMappingURL=invisibles-pPDcY9Vu.js.map
